==> hyades.source_1.0.4.1.zip: org/eclipse/hyades/trace/ui/internal/preferences/TraceViewPreferencePage.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.preferences;

import org.eclipse.swt.layout.*;
import org.eclipse.swt.widgets.*;
import org.eclipse.swt.SWT;
import org.eclipse.hyades.trace.ui.*;
import org.eclipse.hyades.trace.internal.ui.*;
import org.eclipse.hyades.trace.ui.internal.core.*;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.ui.*;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

/*
* CONTEXT_ID tvpp0000 for Monitors View preference page
*/

/*
 * The page for setting java plugin preferences.
 */
public class TraceViewPreferencePage extends PreferencePage
									 implements IWorkbenchPreferencePage
{
	private TraceViewOptionsUI _options;

	public TraceViewPreferencePage()
	{
		super();
		setPreferenceStore(UIPlugin.getDefault().getPreferenceStore());

	}
	protected Control createContents(Composite parent)
	{
		Composite composite= new Composite(parent, SWT.NONE);	
		
		org.eclipse.ui.help.WorkbenchHelp.setHelp(
		parent,
		UIPlugin.getPluginId()+".tvpp0000");
		
		GridLayout layout= new GridLayout();
		layout.marginWidth= 0;
		layout.marginHeight= 5;	
		layout.numColumns= 1;		
		composite.setLayout(layout);
		
		_options = new TraceViewOptionsUI();
		_options.createControl(composite);

		return composite;
	}
/**
 * Returns preference store that belongs to the our plugin.
 * This is important because we want to store
 * our preferences separately from the desktop.
 *
 * @return the preference store for this plugin
 */
protected IPreferenceStore doGetPreferenceStore() {
	return UIPlugin.getDefault().getPreferenceStore();
}
	public void init(IWorkbench workbench) {
	}
/**
 * Initializes states of the controls using default values
 * in the preference store.
 */
private void initializeDefaults()
{
	IPreferenceStore store = getPreferenceStore();

	_options.setShowFolder(store.getDefaultBoolean(TraceConstants.SHOW_FOLDER_KEY));
	_options.setShowMonitor(store.getDefaultBoolean(TraceConstants.SHOW_MON_KEY));
	_options.setShowNode(store.getDefaultBoolean(TraceConstants.SHOW_NODE_KEY));
	_options.setShowProcess(store.getDefaultBoolean(TraceConstants.SHOW_PROCESS_KEY));
	_options.setShowLog(store.getDefaultBoolean(TraceConstants.SHOW_LOG_KEY));
	_options.setShowProf(store.getDefaultBoolean(TraceConstants.SHOW_PROF_KEY));
}
/**
 * Does anything necessary because the default button has been pressed.
 */
protected void performDefaults() {
	super.performDefaults();
	initializeDefaults();

	updateTraceView();
}
/**
 * Do anything necessary because the OK button has been pressed.
 *
 * @return whether it is okay to close the preference page
 */
public boolean performOk() {
	storeValues();
	updateTraceView();
	UIPlugin.getDefault().savePluginPreferences();
	return true;
}
/**
 * Stores the values of the controls back to the preference store.
 */
private void storeValues()
{
	IPreferenceStore store = getPreferenceStore();

	store.setValue(TraceConstants.SHOW_FOLDER_KEY, _options.getShowFolder());
	store.setValue(TraceConstants.SHOW_MON_KEY, _options.getShowMonitor());
	store.setValue(TraceConstants.SHOW_NODE_KEY, _options.getShowNode());
	store.setValue(TraceConstants.SHOW_PROCESS_KEY, _options.getShowProcess());
	store.setValue(TraceConstants.SHOW_LOG_KEY, _options.getShowLog());	
	store.setValue(TraceConstants.SHOW_PROF_KEY, _options.getShowProf());
}
/**
 * Insert the method's description here.
 * Creation date: (5/11/2001 11:41:01 AM)
 */
private void updateTraceView()
{
	//reset filters on all trace views
	final IWorkbenchWindow window= UIPlugin.getActiveWorkbenchWindow();
	if(window == null)
	  return ;

	IWorkbenchPage[] persps = window.getPages();
	for(int idx=0; idx<persps.length; idx++)
	{
		if(persps[idx].getPerspective().getId().equals(PDPerspective.ID_TRACE_PERSPECTIVE))
		{//trace perspective
			IWorkbenchPage page = persps[idx];

			IViewPart view = page.findView(PDPerspective.ID_PD_NAVIGATOR_VIEW);
			if(view != null)
			{
				PDProjectViewer pview = ((PDProjectExplorer) view).getViewer();

				pview.showFolderAction().setChecked(_options.getShowFolder(), false);
				pview.showMonitorAction().setChecked(_options.getShowMonitor(), false);
				pview.showNodesAction().setChecked(_options.getShowNode(), false);
				pview.showProcessAction().setChecked(_options.getShowProcess(), false);
				pview.showProfAgentsAction().setChecked(_options.getShowProf(), false);

				if(pview.showLogAgentsAction() != null)
					pview.showLogAgentsAction().setChecked(_options.getShowLog(), false);
					
				pview.refresh();
			}
		}
	}
	
}
}

==> hyades.source_1.2.2_20040226_1349.zip: org/eclipse/hyades/trace/ui/internal/preferences/TraceViewPreferencePage.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.preferences;

import org.eclipse.swt.layout.*;
import org.eclipse.swt.widgets.*;
import org.eclipse.swt.SWT;
import org.eclipse.hyades.trace.ui.*;
import org.eclipse.hyades.trace.internal.ui.*;
import org.eclipse.hyades.trace.ui.internal.core.*;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.ui.*;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

/*
* CONTEXT_ID tvpp0000 for Monitors View preference page
*/

/*
 * The page for setting java plugin preferences.
 */
public class TraceViewPreferencePage extends PreferencePage
									 implements IWorkbenchPreferencePage
{
	private TraceViewOptionsUI _options;

	public TraceViewPreferencePage()
	{
		super();
		setPreferenceStore(UIPlugin.getDefault().getPreferenceStore());

	}
	protected Control createContents(Composite parent)
	{
		Composite composite= new Composite(parent, SWT.NONE);	
		
		org.eclipse.ui.help.WorkbenchHelp.setHelp(
		parent,
		UIPlugin.getPluginId()+".tvpp0000");
		
		GridLayout layout= new GridLayout();
		layout.marginWidth= 0;
		layout.marginHeight= 5;	
		layout.numColumns= 1;		
		composite.setLayout(layout);
		
		_options = new TraceViewOptionsUI();
		_options.createControl(composite);

		return composite;
	}
/**
 * Returns preference store that belongs to the our plugin.
 * This is important because we want to store
 * our preferences separately from the desktop.
 *
 * @return the preference store for this plugin
 */
protected IPreferenceStore doGetPreferenceStore() {
	return UIPlugin.getDefault().getPreferenceStore();
}
	public void init(IWorkbench workbench) {
	}
/**
 * Initializes states of the controls using default values
 * in the preference store.
 */
private void initializeDefaults()
{
	IPreferenceStore store = getPreferenceStore();

	_options.setShowFolder(store.getDefaultBoolean(TraceConstants.SHOW_FOLDER_KEY));
	_options.setShowMonitor(store.getDefaultBoolean(TraceConstants.SHOW_MON_KEY));
	_options.setShowNode(store.getDefaultBoolean(TraceConstants.SHOW_NODE_KEY));
	_options.setShowProcess(store.getDefaultBoolean(TraceConstants.SHOW_PROCESS_KEY));
	_options.setShowLog(store.getDefaultBoolean(TraceConstants.SHOW_LOG_KEY));
	_options.setShowProf(store.getDefaultBoolean(TraceConstants.SHOW_PROF_KEY));
}
/**
 * Does anything necessary because the default button has been pressed.
 */
protected void performDefaults() {
	super.performDefaults();
	initializeDefaults();

	updateTraceView();
}
/**
 * Do anything necessary because the OK button has been pressed.
 *
 * @return whether it is okay to close the preference page
 */
public boolean performOk() {
	storeValues();
	updateTraceView();
	UIPlugin.getDefault().savePluginPreferences();
	return true;
}
/**
 * Stores the values of the controls back to the preference store.
 */
private void storeValues()
{
	IPreferenceStore store = getPreferenceStore();

	store.setValue(TraceConstants.SHOW_FOLDER_KEY, _options.getShowFolder());
	store.setValue(TraceConstants.SHOW_MON_KEY, _options.getShowMonitor());
	store.setValue(TraceConstants.SHOW_NODE_KEY, _options.getShowNode());
	store.setValue(TraceConstants.SHOW_PROCESS_KEY, _options.getShowProcess());
	store.setValue(TraceConstants.SHOW_LOG_KEY, _options.getShowLog());	
	store.setValue(TraceConstants.SHOW_PROF_KEY, _options.getShowProf());
}
/**
 * Insert the method's description here.
 * Creation date: (5/11/2001 11:41:01 AM)
 */
private void updateTraceView()
{
	//reset filters on all trace views
	final IWorkbenchWindow window= UIPlugin.getActiveWorkbenchWindow();
	if(window == null)
	  return ;

	IWorkbenchPage[] persps = window.getPages();
	for(int idx=0; idx<persps.length; idx++)
	{
		if(persps[idx].getPerspective().getId().equals(PDPerspective.ID_TRACE_PERSPECTIVE))
		{//trace perspective
			IWorkbenchPage page = persps[idx];

			IViewPart view = page.findView(PDPerspective.ID_PD_NAVIGATOR_VIEW);
			if(view != null)
			{
				PDProjectExplorer viewer = (PDProjectExplorer) view;
				viewer.updateActionBars();
				viewer.refresh();
			}
		}
	}
	
}
}
